@@ -50,6 +50,6 @@ def get_pipedrive_client(api_token:str, domain:str) -> Callable:
             return resources
         else:
             return common_client(method, base_url,
-                                 path=path, parameters=parameters, data=data, url=url, headers=headers)
+                                 path=path, parameters=_params, data=data, url=url, headers=headers)
 
     return pipedrive_client
